=======
History
=======

0.1.2 (2018-12-27)
------------------

* Added Authentication and session management required for accessing privileged Organization members
  list

0.1.0 (2018-12-10)
------------------

* Initial commit
